# django-resume
A pluggable framework for managing your resume

## Installation

```bash
pip install django-resume
```

## Running Tests

```bash
pytest
```

## Run mypy

```bash
uv run mypy src
```

## Run coverage

```bash
coverage run -m pytest
coverage report
```

## Run the javascript tests

```bash
npx vitest run
```